@@ -31,6 +31,11 @@
 	<Key>Linefeed: \\n\
 	Ctrl<Key>m: \\n\
 	Ctrl<Key>j:",
+"XVkbd.form.completion_list.background: floralwhite",
+"XVkbd.form.completion_list.columnSpacing: 4",
+"XVkbd.form.completion_list.translations: #override \
+	 <Btn1Down>:   Set()\\n\
+	 <Btn1Up>:     Notify()",
 "XVkbd*Repeater.initialDelay: 600",
 "XVkbd*Repeater.minimumDelay: 100",
 "XVkbd*Repeater.decay: 500",
@@ -41,6 +46,7 @@
 "XVkbd*keypadFont: -*-helvetica-medium-r-*-*-10-*-*-*-*-*-iso8859-1",
 "XVkbd*banner.font: -*-lucida-bold-i-*-*-14-*-*-*-*-*-iso8859-1",
 "XVkbd*display_panel*label.font: -*-helvetica-bold-r-*-*-12-*-*-*-*-*-iso8859-1",
+"XVkbd*completion_list.font: -*-lucida-medium-r-*-*-14-*-*-*-*-*-iso8859-1",
 "XVkbd*beNiceToColormap: false",
 "XVkbd*topShadowContrast: 40",
 "XVkbd*bottomShadowContrast: 80",
@@ -140,8 +146,18 @@
 "XVkbd*props_panel*quick_modifiers.label: Enable \"Quick Modifiers\"?",
 "XVkbd*props_panel*use_xtest.label: Use XTEST Extension?",
 "XVkbd*props_panel*jump_pointer.label: Jump Pointer?",
-"XVkbd*props_panel*dict_entry_label.label: Completion Dictionary: ",
+"XVkbd*props_panel*completion_label.label: Completion:",
+"XVkbd*props_panel*completion_label.vertDistance: 10",
+"XVkbd*props_panel*dict_entry_label.label: Static Dictionary: ",
+"XVkbd*props_panel*dict_entry_label.horizDistance: 40",
 "XVkbd*props_panel*dict_default_button.label: Default",
+"XVkbd*props_panel*private_dict_weight_label.label: Dynamic Dictionary Weight:",
+"XVkbd*props_panel*private_dict_weight_label.horizDistance: 40",
+"XVkbd*props_panel*private_dict_weight_entry.width: 50",
+"XVkbd*props_panel*insert_blank_after_completion.label: Insert Blank after Completion?",
+"XVkbd*props_panel*integrate_completion_panel.label: Integrate Completion Panel?",
+"XVkbd*props_panel*insert_blank_after_completion.horizDistance: 40",
+"XVkbd*props_panel*integrate_completion_panel.horizDistance: 40",
 "XVkbd*props_panel*click.label: Key-Click Sound:",
 "XVkbd*props_panel*autoclick.label: Automatic Click:",
 "XVkbd*props_panel*Command.internalWidth: 4",
@@ -188,10 +204,10 @@
 "XVkbd*completion_panel*view.allowVert: true",
 "XVkbd*completion_panel*view.useRight: true",
 "XVkbd*completion_panel*view.forceBars: true",
-"XVkbd*completion_panel*view.list.width: 400",
-"XVkbd*completion_panel*view.list.height: 150",
+"XVkbd*completion_panel*view.completion_list.width: 400",
+"XVkbd*completion_panel*view.completion_list.height: 150",
 "XVkbd*completion_panel*label.font: -*-helvetica-bold-r-*-*-12-*-*-*-*-*-iso8859-1",
-"XVkbd*completion_panel*list.font: -*-lucida-medium-r-*-*-14-*-*-*-*-*-iso8859-1",
+"XVkbd*completion_panel*completion_list.font: -*-lucida-medium-r-*-*-14-*-*-*-*-*-iso8859-1",
 "XVkbd*completion_panel*label.label: Completion:",
 "XVkbd*completion_panel*bottom: chainTop",
 "XVkbd*completion_panel*label.right: chainLeft",
