@@ -105,6 +105,11 @@ struct appres_struct {
   int key_click_pitch;
   int key_click_duration;
   int autoclick_delay;
+
+  int save_private_dict_interval;
+  float private_dict_decay;
+  Boolean insert_blank_after_completion;
+  Boolean integrate_completion_panel;
 } appres;
 
 
